@@ -1,6 +1,7 @@
 """
 RestApi
 """
+
 from ..component.utils import is_valid_uuid
 from .http_util import http
 
@@ -12,10 +13,9 @@ class RestApi:
 
     # pylint: disable=redefined-builtin
     def __init__(self, endpoint, id=None):
-        is_valid_uuid(id, ignore_none=True)
+        is_valid_uuid(id, allow_none=True)
         self._id = id
         self._endpoint = endpoint
-        self._info = None
 
     def _url(self, method):
         url = f"{self._endpoint}"
@@ -25,16 +25,6 @@ class RestApi:
             url += f"/{method}"
         return url
 
-    # pylint: disable=redefined-builtin
-    def init_id(self, id):
-        """
-        Init id, run only once
-        """
-        if self._id is None:
-            self._id = id
-        else:
-            raise RuntimeError('"id" already set, change of "id" is not allowed.')
-
     def get(self, path=None, method=None, json=None, params=None):
         """
         Resource get
@@ -58,3 +48,9 @@ class RestApi:
         Resource delete
         """
         return http.delete(path or self._url(method))
+
+    def patch(self, json, path=None, method=None):
+        """
+        Resource patch
+        """
+        return http.patch(path or self._url(method), json=json)
